@@ -50,7 +50,7 @@ public:
     struct UndoHtmlVersion {
         QString originalHtml;
         QString plainText;
-        Q_REQUIRED_RESULT bool isValid() const
+        [[nodiscard]] bool isValid() const
         {
             return !originalHtml.isEmpty() && !plainText.isEmpty();
         }
@@ -67,7 +67,7 @@ public:
 };
 
 RichTextComposer::RichTextComposer(QWidget *parent)
-    : KPIMTextEdit::RichTextEditor(parent)
+    : TextCustomEditor::RichTextEditor(parent)
     , d(new RichTextComposerPrivate(this))
 {
     setAcceptRichText(false);
@@ -100,7 +100,7 @@ KPIMTextEdit::RichTextComposerActions *RichTextComposer::composerActions() const
     return d->richTextComposerActions;
 }
 
-QVector<QAction *> RichTextComposer::richTextActionList() const
+QList<QAction *> RichTextComposer::richTextActionList() const
 {
     return d->richTextComposerActions->richTextActionList();
 }
@@ -398,7 +398,7 @@ void RichTextComposer::evaluateListSupport(QKeyEvent *event)
     }
 
     if (!handled) {
-        KPIMTextEdit::RichTextEditor::keyPressEvent(event);
+        TextCustomEditor::RichTextEditor::keyPressEvent(event);
     }
 
     // Match the behavior of office suites: newline after header switches to normal text
@@ -564,7 +564,7 @@ void RichTextComposer::insertFromMimeData(const QMimeData *source)
         }
     }
 
-    KPIMTextEdit::RichTextEditor::insertFromMimeData(source);
+    TextCustomEditor::RichTextEditor::insertFromMimeData(source);
 }
 
 bool RichTextComposer::canInsertFromMimeData(const QMimeData *source) const
@@ -581,7 +581,7 @@ bool RichTextComposer::canInsertFromMimeData(const QMimeData *source) const
         return true;
     }
 
-    return KPIMTextEdit::RichTextEditor::canInsertFromMimeData(source);
+    return TextCustomEditor::RichTextEditor::canInsertFromMimeData(source);
 }
 
 void RichTextComposer::mouseReleaseEvent(QMouseEvent *event)
@@ -590,7 +590,7 @@ void RichTextComposer::mouseReleaseEvent(QMouseEvent *event)
         d->composerControler->disablePainter();
         d->richTextComposerActions->uncheckActionFormatPainter();
     }
-    KPIMTextEdit::RichTextEditor::mouseReleaseEvent(event);
+    TextCustomEditor::RichTextEditor::mouseReleaseEvent(event);
 }
 
 void RichTextComposer::slotTextModeChanged(KPIMTextEdit::RichTextComposer::Mode mode)
@@ -598,3 +598,5 @@ void RichTextComposer::slotTextModeChanged(KPIMTextEdit::RichTextComposer::Mode
     d->composerControler->textModeChanged(mode);
     d->richTextComposerActions->textModeChanged(mode);
 }
+
+#include "moc_richtextcomposer.cpp"
