@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,7 +24,7 @@ public:
     explicit RichTextComposerWidget(QWidget *parent = nullptr);
     ~RichTextComposerWidget() override;
 
-    Q_REQUIRED_RESULT KPIMTextEdit::RichTextComposer *richTextComposer() const;
+    [[nodiscard]] KPIMTextEdit::RichTextComposer *richTextComposer() const;
 
 private:
     std::unique_ptr<RichTextComposerWidgetPrivate> const d;
