@@ -7,7 +7,7 @@
 
 #include "inserthtmleditor.h"
 #include "kpimtextedit_debug.h"
-#include "texteditorcompleter.h"
+#include <TextCustomEditor/TextEditorCompleter>
 
 #include <KSyntaxHighlighting/Definition>
 #include <KSyntaxHighlighting/SyntaxHighlighter>
@@ -20,8 +20,8 @@
 using namespace KPIMTextEdit;
 
 InsertHtmlEditor::InsertHtmlEditor(QWidget *parent)
-    : KPIMTextEdit::PlainTextEditor(parent)
-    , mTextEditorCompleter(new KPIMTextEdit::TextEditorCompleter(this, this))
+    : TextCustomEditor::PlainTextEditor(parent)
+    , mTextEditorCompleter(new TextCustomEditor::TextEditorCompleter(this, this))
 {
     const KSyntaxHighlighting::Definition def = mRepo.definitionForName(QStringLiteral("HTML"));
     if (!def.isValid()) {
@@ -56,6 +56,8 @@ void InsertHtmlEditor::keyPressEvent(QKeyEvent *e)
             break;
         }
     }
-    KPIMTextEdit::PlainTextEditor::keyPressEvent(e);
+    TextCustomEditor::PlainTextEditor::keyPressEvent(e);
     mTextEditorCompleter->completeText();
 }
+
+#include "moc_inserthtmleditor.cpp"
